@@ -1,5 +1,6 @@
 package Finance::Bitcoin::Feed::Site::BitStamp;
 use strict;
+use Finance::Bitcoin::Feed::Site::BitStamp::Socket;
 use Mojo::Base 'Finance::Bitcoin::Feed::Site';
 
 our $VERSION = '0.01';
@@ -11,40 +12,11 @@ sub go {
     my $self = shift;
     $self->SUPER::go;
     $self->debug('connecting...');
-    $self->socket(Finance::Bitcoin::Feed::BitStamp::Socket->new($self));
-    $self->socket->go;
-}
-
-package Finance::Bitcoin::Feed::BitStamp::Socket;
-
-use strict;
-use warnings;
-use parent qw(Finance::Bitcoin::Feed::Pusher);
-use Scalar::Util qw(weaken);
-
-sub new {
-    my $self = shift->SUPER::new(channels => [qw/live_trades/]);
-    $self->{owner} = shift;
-
-    #weaken it to prevent from crossing reference
-    weaken($self->{owner});
-    return $self;
-}
-
-sub trade {
-    my $self = shift;
-    my $data = shift;
-    $self->{owner}->emit('data_out', 0, "BTCUSD", $data->{price});
-}
-
-sub go {
-    my $self = shift;
-    $self->setup;
-    $self->handle;
+    $self->socket(Finance::Bitcoin::Feed::Site::BitStamp::Socket->new($self));
+    return $self->socket->go;
 }
 
 1;
-
 __END__
 
 =head1 NAME
